import React, { useState } from 'react';
import ReactDOM from 'react-dom';
import { interpolateYlOrRd, interpolateYlGn, scaleSequential, max, vsg } from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useData } from './useData';
import { useCodes } from './useCodes';
import { Marks } from './Marks';
import { Dropdown } from './Dropdown';
import { Legend } from './Legend';
import { Title } from './Title';

const width = 960;
const height = 500;

const App = () => {
  const worldAtlas = useWorldAtlas();
  const data = useData();
  const codes = useCodes();
  const options = [
    { label: 'impacto', value: 'impact' },
    { label: 'presencia', value: 'presence' },
    { label: 'apertura', value: 'opening' },
    { label: 'excelencia', value: 'excellence' },
    { label: 'errores de accessibilidad', value: 'accessibilityErrors' },
    { label: 'alertas de accessibilidad', value: 'accessibilityAlerts' },
    { label: 'características de accessibilidad', value: 'accessibilityFeatures' },
    { label: 'errores de contraste', value: 'contrastErrors' },
  ];

  const [value, setValue] = React.useState('impact');

  const handleChange = (event) => {
    setValue(event.target.value);
  };


  if (!worldAtlas || !data || !codes) {
    return <pre>Loading...</pre>;
  }

  const numericCodeByAlphaCode = new Map();
  codes.forEach(code => {
    const alpha3Code = code['alpha-3'];
    const numericCode = code['country-code'];
    numericCodeByAlphaCode.set(alpha3Code, numericCode);
  });
  const rowByNumericCode = new Map();
  data.forEach(row => {
    const alpha3Code = row.code;
    const numericCode = numericCodeByAlphaCode.get(alpha3Code);
    rowByNumericCode.set(numericCode, row);
  });
  const colorValue = d => d[value];
	const domain = value.includes('Alerts') || value.includes('Errors') ? 
        	[0, max(data, colorValue)] : [max(data, colorValue), 0];
  const color = value.includes('Alerts') || value.includes('Errors') ? 
        	interpolateYlOrRd : interpolateYlGn;
  const colorScale = scaleSequential(color)
    .domain(domain)
  var svg = d3.select("#my_dataviz")

	// Handmade legend
 const colorLegendG = svg.append('g')
    .attr('transform', `translate(40,310)`);
 const currentParameter = options.find(o => o.value === value).label;
  return (
    <>
      <Dropdown
        label="Parámetro: "
        options={options}
        value={value}
        onChange={handleChange}
      />
    <svg width={width} height={height}>
      <Marks
        worldAtlas={worldAtlas}
        rowByNumericCode={rowByNumericCode}
        colorScale={colorScale}
        colorValue={colorValue}
      />
      <Title 
        canvasWidth={width}
        canvasHeight={height}
        title={`Mapa de ${currentParameter} en sitios web universitarios`}
      />
      <Legend
        canvasWidth={width}
        canvasHeight={height}
        width={180}
        height={30}
        maxValue={max(data, colorValue)}
        minValue={0}
        variable={currentParameter}
      />
    </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement)